@@ -9,51 +9,61 @@
     :license: MIT, see License for more details.
 """
 
+import os
 import subprocess
 from .package import Package
+from .command import Command
 from .utils import dumps_list
 from .base_classes import BaseLaTeXContainer
 
 
 class Document(BaseLaTeXContainer):
 
-    """A class that contains a full latex document."""
+    """
+    A class that contains a full latex document. If needed, you can append
+    stuff to the preamble or the packages if needed.
+    """
 
     def __init__(self, filename='default_filename', documentclass='article',
                  fontenc='T1', inputenc='utf8', author=None, title=None,
                  date=None, data=None):
         self.filename = filename
 
-        self.documentclass = documentclass
+        if isinstance(documentclass, Command):
+            self.documentclass = documentclass
+        else:
+            self.documentclass = Command('documentclass',
+                                         arguments=documentclass)
 
-        fontenc = Package('fontenc', option=fontenc)
-        inputenc = Package('inputenc', option=inputenc)
-        packages = [fontenc, inputenc, Package('lmodern')]
+        fontenc = Package('fontenc', options=fontenc)
+        inputenc = Package('inputenc', options=inputenc)
+        lmodern = Package('lmodern')
+        packages = [fontenc, inputenc, lmodern]
+
+        self.preamble = []
 
         if title is not None:
-            packages.append(Package(title, base='title'))
+            self.preamble.append(Command('title', title))
         if author is not None:
-            packages.append(Package(author, base='author'))
+            self.preamble.append(Command('author', author))
         if date is not None:
-            packages.append(Package(date, base='date'))
+            self.preamble.append(Command('date', date))
 
         super().__init__(data, packages=packages)
 
     def dumps(self):
         """Represents the document as a string in LaTeX syntax."""
-        document = r'\begin{document}'
+        document = r'\begin{document}' + os.linesep
 
-        document += dumps_list(self)
+        document += super().dumps() + os.linesep
 
-        document += r'\end{document}'
+        document += r'\end{document}' + os.linesep
 
-        super().dumps()
+        head = self.documentclass.dumps() + os.linesep
+        head += self.dumps_packages() + os.linesep
+        head += dumps_list(self.preamble) + os.linesep
 
-        head = r'\documentclass{' + self.documentclass + '}'
-
-        head += self.dumps_packages()
-
-        return head + document
+        return head + os.linesep + document
 
     def generate_tex(self):
         """Generates a .tex file."""
@@ -68,7 +78,7 @@ class Document(BaseLaTeXContainer):
         command = 'pdflatex --jobname="' + self.filename + '" "' + \
             self.filename + '.tex"'
 
-        subprocess.call(command, shell=True)
+        subprocess.check_call(command, shell=True)
 
         if clean:
             subprocess.call('rm "' + self.filename + '.aux" "' +
