@@ -3,8 +3,8 @@
 from __future__ import absolute_import
 import numpy as np
 
-from pylatex import Document, Section, Subsection, Table, Math
-from pylatex.numpy import Matrix, format_vec
+from pylatex import Document, Section, Subsection, Math
+from pylatex.numpy import Matrix, VectorName
 
 
 a = np.array([[100, 10, 20]]).T
@@ -14,7 +14,7 @@ section = Section(u'Numpy tests')
 subsection = Subsection(u'Array')
 
 vec = Matrix(a)
-vec_name = format_vec(u'a')
+vec_name = VectorName(u'a')
 math = Math(data=[vec_name, u'=', vec])
 
 subsection.append(math)
