@@ -1,5 +1,4 @@
 from __future__ import absolute_import
-from .utils import dumps_list
 from .base_classes import BaseLaTeXContainer
 
 
@@ -11,9 +10,9 @@ class Math(BaseLaTeXContainer):
 
     def dumps(self):
         if self.inline:
-            string = u'$' + dumps_list(self, token=u' ') + u'$'
+            string = u'$' + super(Math, self).dumps(token=u' ') + u'$'
         else:
-            string = u'$$' + dumps_list(self, token=u' ') + u'$$\n'
+            string = u'$$' + super(Math, self).dumps(token=u' ') + u'$$\n'
 
         super(Math, self).dumps()
         return string
