@@ -12,6 +12,7 @@ u"""
 from __future__ import absolute_import
 from .utils import dumps_list
 from .base_classes import BaseLaTeXContainer
+from .command import Command
 
 
 class SectionBase(BaseLaTeXContainer):
@@ -33,8 +34,9 @@ class SectionBase(BaseLaTeXContainer):
         else:
             num = u''
 
-        base = u'\\' + self.__class__.__name__.lower() + num
-        string = base + u'{' + self.title + u'}\n' + dumps_list(self)
+        section_type = self.__class__.__name__.lower()
+        string = Command(section_type + num, self.title).dumps()
+        string += dumps_list(self)
 
         super(SectionBase, self).dumps()
         return string
